Crate youtui_vendored_rusty_ytdl

Crate youtui_vendored_rusty_ytdl 

Re-exports

pub extern crate flame;

Re-exports

pub use reqwest;

Modules

blocking
constants
search
stream

Macros

block_async

Structs

Author
Chapter
ColorInfo
DownloadOptions
Video download options
Embed
FFmpegArgs
MimeType
RangeObject
RelatedVideo
RequestOptions
StoryBoard
Thumbnail
Video
If a video was created with a reference to options, it is tied to their lifetime 'opts.
VideoDetails
VideoFormat
VideoInfo
VideoOptions
Video search and download options

Enums

VideoError
VideoQuality
VideoSearchOptions

Functions

choose_format
Try to get format with VideoOptions filter
get_random_v6_ip
Try to generate IPv6 with custom valid block
get_video_id
Excavate video id from URLs or id with Regex